<?php

namespace PlaySms\PlaySms\Observer;

use PlaySms\PlaySms\PlaySmsVendor\SendSms;

class NewCustomerObserver implements \Magento\Framework\Event\ObserverInterface
{
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $currentHook = 'new_account';
        $customerId = $observer->getCustomerAddress()->getCustomerId();
        $customerPhoneNumber = $observer->getCustomerAddress()->getTelephone();
        $customerFirstName = $observer->getCustomerAddress()->getFirstname();
        $customerLastName = $observer->getCustomerAddress()->getLastname();
        $customerCity = $observer->getCustomerAddress()->getCity();
        $customerPostcode = $observer->getCustomerAddress()->getPostcode();
        $customerStreet = implode('/', $observer->getCustomerAddress()->getStreet());
        
        if(!empty($customerPhoneNumber)){
            
            $this->_resources = \Magento\Framework\App\ObjectManager::getInstance()
                    ->get('Magento\Framework\App\ResourceConnection');
            $connection = $this->_resources->getConnection();
            
            $select = $connection->select()
                ->from(
                    ['o' =>  $this->_resources->getTableName('playsms_playsms_config')]
                );

            $result = $connection->fetchAll($select);

            $smsApiKey = $result[0]['api_key'];
            $smsPassword = $result[0]['password'];

            $select = $connection->select()
                ->from(
                    ['o' =>  $this->_resources->getTableName('playsms_playsms_events')]
                );

            $events = $connection->fetchAll($select);

            $messages = [];
            foreach($events as $event){
                if($event['action_type'] == $currentHook){
                    $currText = $event['sms_content'];
                    $currText = str_replace('{{IMIE}}', $customerFirstName, $currText);
                    $currText = str_replace('{{NAZWISKO}}', $customerLastName, $currText);
                    $currText = str_replace('{{ULICA}}', $customerStreet, $currText);
                    $currText = str_replace('{{KOD_POCZTOWY}}', $customerPostcode, $currText);
                    $currText = str_replace('{{MIEJSCOWOSC}}', $customerCity, $currText);
                    $currText = str_replace("\r\n", ' ', $currText);
                    
                    $messages[] = [
                        'sender' => $event['sender'],
                        'sms_content' => $currText,
                        'clear_polish' => $event['clear_polish']
                    ];
                }
            }
            
            $smsObj = new SendSms($smsApiKey, $smsPassword, $customerPhoneNumber, 'test', 0, 'test', 0); 
            $error = false;
            foreach($messages as $message){
                
                $smsObj->setHeader($message['sender']);
                $smsObj->setMessage($message['sms_content']);
                $smsObj->clearPolish($message['clear_polish']);
                $result = $smsObj->send();
                $xmlResult = simplexml_load_string($result);
                
                if($xmlResult->result != 'OK'){
                    $error = true;
                    $errorTime = date('Y-m-d H:i:s');
                    $errorDesc = $xmlResult->errorMsg;
                    $errorHook = $currentHook;
                    
                    $table = $this->_resources->getTableName('playsms_playsms_sms_errors');
                    $sql = "INSERT INTO " . $table . " SET date=:errorTime, description=:errorDesc, action=:errorHook";
                    
                    $binds = array(
                        'errorTime' => $errorTime,
                        'errorDesc' => $errorDesc,
                        'errorHook' => $errorHook
                    );
                    
                    $connection->query($sql, $binds);
                }
            }
            
            if(!$error){
                $table = $this->_resources->getTableName('playsms_playsms_greeted_users');
                $sql = "INSERT INTO " . $table . "(customer_id) VALUES ('$customerId')";
                $connection->query($sql);
            }
        }

        return $this;
    }
}